'''_3610.py

BevelDifferentialGearSetCompoundStabilityAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2223
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.stability_analyses.compound import _3608, _3609, _3615
from mastapy.system_model.analyses_and_results.stability_analyses import _3477
from mastapy._internal.python_net import python_net_import

_BEVEL_DIFFERENTIAL_GEAR_SET_COMPOUND_STABILITY_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StabilityAnalyses.Compound', 'BevelDifferentialGearSetCompoundStabilityAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('BevelDifferentialGearSetCompoundStabilityAnalysis',)


class BevelDifferentialGearSetCompoundStabilityAnalysis(_3615.BevelGearSetCompoundStabilityAnalysis):
    '''BevelDifferentialGearSetCompoundStabilityAnalysis

    This is a mastapy class.
    '''

    TYPE = _BEVEL_DIFFERENTIAL_GEAR_SET_COMPOUND_STABILITY_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BevelDifferentialGearSetCompoundStabilityAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2223.BevelDifferentialGearSet':
        '''BevelDifferentialGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2223.BevelDifferentialGearSet)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2223.BevelDifferentialGearSet':
        '''BevelDifferentialGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2223.BevelDifferentialGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def bevel_differential_gears_compound_stability_analysis(self) -> 'List[_3608.BevelDifferentialGearCompoundStabilityAnalysis]':
        '''List[BevelDifferentialGearCompoundStabilityAnalysis]: 'BevelDifferentialGearsCompoundStabilityAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BevelDifferentialGearsCompoundStabilityAnalysis, constructor.new(_3608.BevelDifferentialGearCompoundStabilityAnalysis))
        return value

    @property
    def bevel_differential_meshes_compound_stability_analysis(self) -> 'List[_3609.BevelDifferentialGearMeshCompoundStabilityAnalysis]':
        '''List[BevelDifferentialGearMeshCompoundStabilityAnalysis]: 'BevelDifferentialMeshesCompoundStabilityAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BevelDifferentialMeshesCompoundStabilityAnalysis, constructor.new(_3609.BevelDifferentialGearMeshCompoundStabilityAnalysis))
        return value

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_3477.BevelDifferentialGearSetStabilityAnalysis]':
        '''List[BevelDifferentialGearSetStabilityAnalysis]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCasesReady, constructor.new(_3477.BevelDifferentialGearSetStabilityAnalysis))
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_3477.BevelDifferentialGearSetStabilityAnalysis]':
        '''List[BevelDifferentialGearSetStabilityAnalysis]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCases, constructor.new(_3477.BevelDifferentialGearSetStabilityAnalysis))
        return value



'''_152.py

FEExportFormat
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_FE_EXPORT_FORMAT = python_net_import('SMT.MastaAPI.NodalAnalysis.FeExportUtility', 'FEExportFormat')


__docformat__ = 'restructuredtext en'
__all__ = ('FEExportFormat',)


class FEExportFormat(Enum):
    '''FEExportFormat

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _FE_EXPORT_FORMAT

    __hash__ = None

    ANSYS_APDL_INPUT_FILE = 0
    ANSYS_WORKBENCH_COMMANDS = 1
    ANSYS_APDL_INPUT_FILE_OUTPUT_SUB = 2
    NASTRAN_BULK_DATA_FILE_OUTPUT_PCH = 3
    NASTRAN_BULK_DATA_FILE_OUTPUT_OP4_AND_PCH = 4
    ABAQUS_INPUT_FILE_OUTPUT_MTX = 5
    ABAQUS_INPUT_FILE_OUTPUT_FIL = 6


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


FEExportFormat.__setattr__ = __enum_setattr
FEExportFormat.__delattr__ = __enum_delattr



'''_756.py

PinionConicalMachineSettingsSpecified
'''


from mastapy.gears.manufacturing.bevel import _758
from mastapy._internal.python_net import python_net_import

_PINION_CONICAL_MACHINE_SETTINGS_SPECIFIED = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Bevel', 'PinionConicalMachineSettingsSpecified')


__docformat__ = 'restructuredtext en'
__all__ = ('PinionConicalMachineSettingsSpecified',)


class PinionConicalMachineSettingsSpecified(_758.PinionFinishMachineSettings):
    '''PinionConicalMachineSettingsSpecified

    This is a mastapy class.
    '''

    TYPE = _PINION_CONICAL_MACHINE_SETTINGS_SPECIFIED

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PinionConicalMachineSettingsSpecified.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_4937.py

ShaftPerModeResult
'''


from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.modal_analyses.reporting import _4930
from mastapy._internal.python_net import python_net_import

_SHAFT_PER_MODE_RESULT = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses.Reporting', 'ShaftPerModeResult')


__docformat__ = 'restructuredtext en'
__all__ = ('ShaftPerModeResult',)


class ShaftPerModeResult(_4930.ComponentPerModeResult):
    '''ShaftPerModeResult

    This is a mastapy class.
    '''

    TYPE = _SHAFT_PER_MODE_RESULT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ShaftPerModeResult.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def torsional_mode_shape(self) -> 'float':
        '''float: 'TorsionalModeShape' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TorsionalModeShape



'''_1104.py

ConicalGearProfileModification
'''


from mastapy.gears.micro_geometry import _534
from mastapy._internal.python_net import python_net_import

_CONICAL_GEAR_PROFILE_MODIFICATION = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Conical.MicroGeometry', 'ConicalGearProfileModification')


__docformat__ = 'restructuredtext en'
__all__ = ('ConicalGearProfileModification',)


class ConicalGearProfileModification(_534.ProfileModification):
    '''ConicalGearProfileModification

    This is a mastapy class.
    '''

    TYPE = _CONICAL_GEAR_PROFILE_MODIFICATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConicalGearProfileModification.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._1691 import BallBearingContactCalculation
    from ._1692 import BallBearingRaceContactGeometry
    from ._1693 import DIN732Results
    from ._1694 import ForceAtLaminaGroupReportable
    from ._1695 import ForceAtLaminaReportable
    from ._1696 import InternalClearance
    from ._1697 import ISO14179Settings
    from ._1698 import ISO14179SettingsDatabase
    from ._1699 import ISO14179SettingsPerBearingType
    from ._1700 import LoadedAbstractSphericalRollerBearingStripLoadResults
    from ._1701 import LoadedAngularContactBallBearingElement
    from ._1702 import LoadedAngularContactBallBearingResults
    from ._1703 import LoadedAngularContactBallBearingRow
    from ._1704 import LoadedAngularContactThrustBallBearingElement
    from ._1705 import LoadedAngularContactThrustBallBearingResults
    from ._1706 import LoadedAngularContactThrustBallBearingRow
    from ._1707 import LoadedAsymmetricSphericalRollerBearingElement
    from ._1708 import LoadedAsymmetricSphericalRollerBearingResults
    from ._1709 import LoadedAsymmetricSphericalRollerBearingRow
    from ._1710 import LoadedAsymmetricSphericalRollerBearingStripLoadResults
    from ._1711 import LoadedAxialThrustCylindricalRollerBearingDutyCycle
    from ._1712 import LoadedAxialThrustCylindricalRollerBearingElement
    from ._1713 import LoadedAxialThrustCylindricalRollerBearingResults
    from ._1714 import LoadedAxialThrustCylindricalRollerBearingRow
    from ._1715 import LoadedAxialThrustNeedleRollerBearingElement
    from ._1716 import LoadedAxialThrustNeedleRollerBearingResults
    from ._1717 import LoadedAxialThrustNeedleRollerBearingRow
    from ._1718 import LoadedBallBearingDutyCycle
    from ._1719 import LoadedBallBearingElement
    from ._1720 import LoadedBallBearingRaceResults
    from ._1721 import LoadedBallBearingResults
    from ._1722 import LoadedBallBearingRow
    from ._1723 import LoadedCrossedRollerBearingElement
    from ._1724 import LoadedCrossedRollerBearingResults
    from ._1725 import LoadedCrossedRollerBearingRow
    from ._1726 import LoadedCylindricalRollerBearingDutyCycle
    from ._1727 import LoadedCylindricalRollerBearingElement
    from ._1728 import LoadedCylindricalRollerBearingResults
    from ._1729 import LoadedCylindricalRollerBearingRow
    from ._1730 import LoadedDeepGrooveBallBearingElement
    from ._1731 import LoadedDeepGrooveBallBearingResults
    from ._1732 import LoadedDeepGrooveBallBearingRow
    from ._1733 import LoadedElement
    from ._1734 import LoadedFourPointContactBallBearingElement
    from ._1735 import LoadedFourPointContactBallBearingRaceResults
    from ._1736 import LoadedFourPointContactBallBearingResults
    from ._1737 import LoadedFourPointContactBallBearingRow
    from ._1738 import LoadedMultiPointContactBallBearingElement
    from ._1739 import LoadedNeedleRollerBearingElement
    from ._1740 import LoadedNeedleRollerBearingResults
    from ._1741 import LoadedNeedleRollerBearingRow
    from ._1742 import LoadedNonBarrelRollerBearingDutyCycle
    from ._1743 import LoadedNonBarrelRollerBearingResults
    from ._1744 import LoadedNonBarrelRollerBearingRow
    from ._1745 import LoadedNonBarrelRollerBearingStripLoadResults
    from ._1746 import LoadedNonBarrelRollerElement
    from ._1747 import LoadedRollerBearingElement
    from ._1748 import LoadedRollerBearingResults
    from ._1749 import LoadedRollerBearingRow
    from ._1750 import LoadedRollerStripLoadResults
    from ._1751 import LoadedRollingBearingRaceResults
    from ._1752 import LoadedRollingBearingResults
    from ._1753 import LoadedRollingBearingRow
    from ._1754 import LoadedSelfAligningBallBearingElement
    from ._1755 import LoadedSelfAligningBallBearingResults
    from ._1756 import LoadedSelfAligningBallBearingRow
    from ._1757 import LoadedSphericalRadialRollerBearingElement
    from ._1758 import LoadedSphericalRollerBearingElement
    from ._1759 import LoadedSphericalRollerRadialBearingResults
    from ._1760 import LoadedSphericalRollerRadialBearingRow
    from ._1761 import LoadedSphericalRollerRadialBearingStripLoadResults
    from ._1762 import LoadedSphericalRollerThrustBearingResults
    from ._1763 import LoadedSphericalRollerThrustBearingRow
    from ._1764 import LoadedSphericalRollerThrustBearingStripLoadResults
    from ._1765 import LoadedSphericalThrustRollerBearingElement
    from ._1766 import LoadedTaperRollerBearingDutyCycle
    from ._1767 import LoadedTaperRollerBearingElement
    from ._1768 import LoadedTaperRollerBearingResults
    from ._1769 import LoadedTaperRollerBearingRow
    from ._1770 import LoadedThreePointContactBallBearingElement
    from ._1771 import LoadedThreePointContactBallBearingResults
    from ._1772 import LoadedThreePointContactBallBearingRow
    from ._1773 import LoadedThrustBallBearingElement
    from ._1774 import LoadedThrustBallBearingResults
    from ._1775 import LoadedThrustBallBearingRow
    from ._1776 import LoadedToroidalRollerBearingElement
    from ._1777 import LoadedToroidalRollerBearingResults
    from ._1778 import LoadedToroidalRollerBearingRow
    from ._1779 import LoadedToroidalRollerBearingStripLoadResults
    from ._1780 import MaximumStaticContactStress
    from ._1781 import MaximumStaticContactStressDutyCycle
    from ._1782 import MaximumStaticContactStressResultsAbstract
    from ._1783 import MaxStripLoadStressObject
    from ._1784 import PermissibleContinuousAxialLoadResults
    from ._1785 import PowerRatingF1EstimationMethod
    from ._1786 import PreloadFactorLookupTable
    from ._1787 import ResultsAtRollerOffset
    from ._1788 import RingForceAndDisplacement
    from ._1789 import RollerAnalysisMethod
    from ._1790 import RollingBearingFrictionCoefficients
    from ._1791 import RollingBearingSpeedResults
    from ._1792 import SMTRibStressResults
    from ._1793 import StressAtPosition
    from ._1794 import ThreePointContactInternalClearance
    from ._1795 import TrackTruncationSafetyFactorResults



'''_6850.py

ComponentCompoundAdvancedTimeSteppingAnalysisForModulation
'''


from typing import List

from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import _6720
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import _6904
from mastapy._internal.python_net import python_net_import

_COMPONENT_COMPOUND_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedTimeSteppingAnalysesForModulation.Compound', 'ComponentCompoundAdvancedTimeSteppingAnalysisForModulation')


__docformat__ = 'restructuredtext en'
__all__ = ('ComponentCompoundAdvancedTimeSteppingAnalysisForModulation',)


class ComponentCompoundAdvancedTimeSteppingAnalysisForModulation(_6904.PartCompoundAdvancedTimeSteppingAnalysisForModulation):
    '''ComponentCompoundAdvancedTimeSteppingAnalysisForModulation

    This is a mastapy class.
    '''

    TYPE = _COMPONENT_COMPOUND_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ComponentCompoundAdvancedTimeSteppingAnalysisForModulation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_analysis_cases(self) -> 'List[_6720.ComponentAdvancedTimeSteppingAnalysisForModulation]':
        '''List[ComponentAdvancedTimeSteppingAnalysisForModulation]: 'ComponentAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCases, constructor.new(_6720.ComponentAdvancedTimeSteppingAnalysisForModulation))
        return value

    @property
    def component_analysis_cases_ready(self) -> 'List[_6720.ComponentAdvancedTimeSteppingAnalysisForModulation]':
        '''List[ComponentAdvancedTimeSteppingAnalysisForModulation]: 'ComponentAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCasesReady, constructor.new(_6720.ComponentAdvancedTimeSteppingAnalysisForModulation))
        return value



'''_1026.py

NominalValueSpecification
'''


from typing import Generic, TypeVar

from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy._internal import constructor
from mastapy.gears.gear_designs.cylindrical import _1019
from mastapy._internal.python_net import python_net_import

_NOMINAL_VALUE_SPECIFICATION = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical.ThicknessStockAndBacklash', 'NominalValueSpecification')


__docformat__ = 'restructuredtext en'
__all__ = ('NominalValueSpecification',)


T = TypeVar('T')


class NominalValueSpecification(_1019.TolerancedValueSpecification['T'], Generic[T]):
    '''NominalValueSpecification

    This is a mastapy class.

    Generic Types:
        T
    '''

    TYPE = _NOMINAL_VALUE_SPECIFICATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'NominalValueSpecification.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def design(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'Design' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.Design) if self.wrapped.Design else None

    @design.setter
    def design(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.Design = value



'''_3924.py

GearMeshCompoundPowerFlow
'''


from typing import List

from mastapy.gears.rating import _330
from mastapy._internal import constructor, conversion
from mastapy.gears.rating.worm import _342
from mastapy._internal.cast_exception import CastException
from mastapy.gears.rating.face import _411
from mastapy.gears.rating.cylindrical import _429
from mastapy.gears.rating.conical import _496
from mastapy.gears.rating.concept import _501
from mastapy.system_model.analyses_and_results.power_flows import _3791
from mastapy.system_model.analyses_and_results.power_flows.compound import _3930
from mastapy._internal.python_net import python_net_import

_GEAR_MESH_COMPOUND_POWER_FLOW = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.PowerFlows.Compound', 'GearMeshCompoundPowerFlow')


__docformat__ = 'restructuredtext en'
__all__ = ('GearMeshCompoundPowerFlow',)


class GearMeshCompoundPowerFlow(_3930.InterMountableComponentConnectionCompoundPowerFlow):
    '''GearMeshCompoundPowerFlow

    This is a mastapy class.
    '''

    TYPE = _GEAR_MESH_COMPOUND_POWER_FLOW

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GearMeshCompoundPowerFlow.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def gear_mesh_duty_cycle_rating(self) -> '_330.MeshDutyCycleRating':
        '''MeshDutyCycleRating: 'GearMeshDutyCycleRating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _330.MeshDutyCycleRating.TYPE not in self.wrapped.GearMeshDutyCycleRating.__class__.__mro__:
            raise CastException('Failed to cast gear_mesh_duty_cycle_rating to MeshDutyCycleRating. Expected: {}.'.format(self.wrapped.GearMeshDutyCycleRating.__class__.__qualname__))

        return constructor.new_override(self.wrapped.GearMeshDutyCycleRating.__class__)(self.wrapped.GearMeshDutyCycleRating) if self.wrapped.GearMeshDutyCycleRating else None

    @property
    def gear_mesh_duty_cycle_rating_of_type_worm_mesh_duty_cycle_rating(self) -> '_342.WormMeshDutyCycleRating':
        '''WormMeshDutyCycleRating: 'GearMeshDutyCycleRating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _342.WormMeshDutyCycleRating.TYPE not in self.wrapped.GearMeshDutyCycleRating.__class__.__mro__:
            raise CastException('Failed to cast gear_mesh_duty_cycle_rating to WormMeshDutyCycleRating. Expected: {}.'.format(self.wrapped.GearMeshDutyCycleRating.__class__.__qualname__))

        return constructor.new_override(self.wrapped.GearMeshDutyCycleRating.__class__)(self.wrapped.GearMeshDutyCycleRating) if self.wrapped.GearMeshDutyCycleRating else None

    @property
    def gear_mesh_duty_cycle_rating_of_type_face_gear_mesh_duty_cycle_rating(self) -> '_411.FaceGearMeshDutyCycleRating':
        '''FaceGearMeshDutyCycleRating: 'GearMeshDutyCycleRating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _411.FaceGearMeshDutyCycleRating.TYPE not in self.wrapped.GearMeshDutyCycleRating.__class__.__mro__:
            raise CastException('Failed to cast gear_mesh_duty_cycle_rating to FaceGearMeshDutyCycleRating. Expected: {}.'.format(self.wrapped.GearMeshDutyCycleRating.__class__.__qualname__))

        return constructor.new_override(self.wrapped.GearMeshDutyCycleRating.__class__)(self.wrapped.GearMeshDutyCycleRating) if self.wrapped.GearMeshDutyCycleRating else None

    @property
    def gear_mesh_duty_cycle_rating_of_type_cylindrical_mesh_duty_cycle_rating(self) -> '_429.CylindricalMeshDutyCycleRating':
        '''CylindricalMeshDutyCycleRating: 'GearMeshDutyCycleRating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _429.CylindricalMeshDutyCycleRating.TYPE not in self.wrapped.GearMeshDutyCycleRating.__class__.__mro__:
            raise CastException('Failed to cast gear_mesh_duty_cycle_rating to CylindricalMeshDutyCycleRating. Expected: {}.'.format(self.wrapped.GearMeshDutyCycleRating.__class__.__qualname__))

        return constructor.new_override(self.wrapped.GearMeshDutyCycleRating.__class__)(self.wrapped.GearMeshDutyCycleRating) if self.wrapped.GearMeshDutyCycleRating else None

    @property
    def gear_mesh_duty_cycle_rating_of_type_conical_mesh_duty_cycle_rating(self) -> '_496.ConicalMeshDutyCycleRating':
        '''ConicalMeshDutyCycleRating: 'GearMeshDutyCycleRating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _496.ConicalMeshDutyCycleRating.TYPE not in self.wrapped.GearMeshDutyCycleRating.__class__.__mro__:
            raise CastException('Failed to cast gear_mesh_duty_cycle_rating to ConicalMeshDutyCycleRating. Expected: {}.'.format(self.wrapped.GearMeshDutyCycleRating.__class__.__qualname__))

        return constructor.new_override(self.wrapped.GearMeshDutyCycleRating.__class__)(self.wrapped.GearMeshDutyCycleRating) if self.wrapped.GearMeshDutyCycleRating else None

    @property
    def gear_mesh_duty_cycle_rating_of_type_concept_gear_mesh_duty_cycle_rating(self) -> '_501.ConceptGearMeshDutyCycleRating':
        '''ConceptGearMeshDutyCycleRating: 'GearMeshDutyCycleRating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _501.ConceptGearMeshDutyCycleRating.TYPE not in self.wrapped.GearMeshDutyCycleRating.__class__.__mro__:
            raise CastException('Failed to cast gear_mesh_duty_cycle_rating to ConceptGearMeshDutyCycleRating. Expected: {}.'.format(self.wrapped.GearMeshDutyCycleRating.__class__.__qualname__))

        return constructor.new_override(self.wrapped.GearMeshDutyCycleRating.__class__)(self.wrapped.GearMeshDutyCycleRating) if self.wrapped.GearMeshDutyCycleRating else None

    @property
    def connection_analysis_cases(self) -> 'List[_3791.GearMeshPowerFlow]':
        '''List[GearMeshPowerFlow]: 'ConnectionAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConnectionAnalysisCases, constructor.new(_3791.GearMeshPowerFlow))
        return value

    @property
    def connection_analysis_cases_ready(self) -> 'List[_3791.GearMeshPowerFlow]':
        '''List[GearMeshPowerFlow]: 'ConnectionAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConnectionAnalysisCasesReady, constructor.new(_3791.GearMeshPowerFlow))
        return value



'''_2115.py

RaceBearingFESystemDeflection
'''


from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_RACE_BEARING_FE_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.FE', 'RaceBearingFESystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('RaceBearingFESystemDeflection',)


class RaceBearingFESystemDeflection(_0.APIBase):
    '''RaceBearingFESystemDeflection

    This is a mastapy class.
    '''

    TYPE = _RACE_BEARING_FE_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RaceBearingFESystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def name(self) -> 'str':
        '''str: 'Name' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Name



'''_1586.py

DutyCyclePropertySummaryPercentage
'''


from typing import Generic, TypeVar

from mastapy._internal import constructor
from mastapy.utility.property import _1584
from mastapy.utility.units_and_measurements.measurements import _1451
from mastapy._internal.python_net import python_net_import

_DUTY_CYCLE_PROPERTY_SUMMARY_PERCENTAGE = python_net_import('SMT.MastaAPI.Utility.Property', 'DutyCyclePropertySummaryPercentage')


__docformat__ = 'restructuredtext en'
__all__ = ('DutyCyclePropertySummaryPercentage',)


T = TypeVar('T')


class DutyCyclePropertySummaryPercentage(_1584.DutyCyclePropertySummary['_1451.Percentage', 'T'], Generic[T]):
    '''DutyCyclePropertySummaryPercentage

    This is a mastapy class.

    Generic Types:
        T
    '''

    TYPE = _DUTY_CYCLE_PROPERTY_SUMMARY_PERCENTAGE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'DutyCyclePropertySummaryPercentage.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def maximum_value(self) -> 'float':
        '''float: 'MaximumValue' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumValue

    @property
    def minimum_value(self) -> 'float':
        '''float: 'MinimumValue' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumValue

    @property
    def average_value(self) -> 'float':
        '''float: 'AverageValue' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AverageValue



'''_1935.py

SystemReporting
'''


from typing import List

from mastapy._internal import constructor, conversion
from mastapy.utility.units_and_measurements import _1380
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_SYSTEM_REPORTING = python_net_import('SMT.MastaAPI.SystemModel', 'SystemReporting')


__docformat__ = 'restructuredtext en'
__all__ = ('SystemReporting',)


class SystemReporting(_0.APIBase):
    '''SystemReporting

    This is a mastapy class.
    '''

    TYPE = _SYSTEM_REPORTING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SystemReporting.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def current_date_and_time(self) -> 'str':
        '''str: 'CurrentDateAndTime' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CurrentDateAndTime

    @property
    def current_date_and_time_iso8601(self) -> 'str':
        '''str: 'CurrentDateAndTimeISO8601' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CurrentDateAndTimeISO8601

    @property
    def masta_version(self) -> 'str':
        '''str: 'MASTAVersion' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MASTAVersion

    @property
    def measurements_not_using_si_unit(self) -> 'List[_1380.MeasurementBase]':
        '''List[MeasurementBase]: 'MeasurementsNotUsingSIUnit' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.MeasurementsNotUsingSIUnit, constructor.new(_1380.MeasurementBase))
        return value

    @property
    def all_measurements(self) -> 'List[_1380.MeasurementBase]':
        '''List[MeasurementBase]: 'AllMeasurements' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AllMeasurements, constructor.new(_1380.MeasurementBase))
        return value



'''_764.py

WheelFormatMachineTypes
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_WHEEL_FORMAT_MACHINE_TYPES = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Bevel', 'WheelFormatMachineTypes')


__docformat__ = 'restructuredtext en'
__all__ = ('WheelFormatMachineTypes',)


class WheelFormatMachineTypes(Enum):
    '''WheelFormatMachineTypes

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _WHEEL_FORMAT_MACHINE_TYPES

    __hash__ = None

    COMPATIBLE_WITH_NO608_609_610 = 0
    COMPATIBLE_WITH_NO606_607 = 1
    UNKNOWN = 2


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


WheelFormatMachineTypes.__setattr__ = __enum_setattr
WheelFormatMachineTypes.__delattr__ = __enum_delattr



'''_2534.py

TorsionalSystemDeflection
'''


from mastapy.system_model.analyses_and_results.system_deflections import _2527
from mastapy._internal.python_net import python_net_import

_TORSIONAL_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections', 'TorsionalSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('TorsionalSystemDeflection',)


class TorsionalSystemDeflection(_2527.SystemDeflection):
    '''TorsionalSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _TORSIONAL_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'TorsionalSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._517 import AGMAGleasonConicalGearMeshRating
    from ._518 import AGMAGleasonConicalGearRating
    from ._519 import AGMAGleasonConicalGearSetRating
    from ._520 import AGMAGleasonConicalRateableMesh



'''_449.py

VDI2737InternalGearSingleFlankRating
'''


from mastapy._internal import constructor
from mastapy.gears.rating.cylindrical.iso6336 import (
    _478, _470, _472, _474
)
from mastapy._internal.cast_exception import CastException
from mastapy.gears.rating.cylindrical.din3990 import _485
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_VDI2737_INTERNAL_GEAR_SINGLE_FLANK_RATING = python_net_import('SMT.MastaAPI.Gears.Rating.Cylindrical.VDI', 'VDI2737InternalGearSingleFlankRating')


__docformat__ = 'restructuredtext en'
__all__ = ('VDI2737InternalGearSingleFlankRating',)


class VDI2737InternalGearSingleFlankRating(_0.APIBase):
    '''VDI2737InternalGearSingleFlankRating

    This is a mastapy class.
    '''

    TYPE = _VDI2737_INTERNAL_GEAR_SINGLE_FLANK_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'VDI2737InternalGearSingleFlankRating.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def rating_name(self) -> 'str':
        '''str: 'RatingName' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RatingName

    @property
    def fatigue_fracture_safety_factor(self) -> 'float':
        '''float: 'FatigueFractureSafetyFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FatigueFractureSafetyFactor

    @property
    def fatigue_fracture_safety_factor_with_influence_of_rim(self) -> 'float':
        '''float: 'FatigueFractureSafetyFactorWithInfluenceOfRim' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FatigueFractureSafetyFactorWithInfluenceOfRim

    @property
    def safety_factor_against_permanent_deformation(self) -> 'float':
        '''float: 'SafetyFactorAgainstPermanentDeformation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SafetyFactorAgainstPermanentDeformation

    @property
    def safety_factor_against_permanent_deformation_with_influence_of_rim(self) -> 'float':
        '''float: 'SafetyFactorAgainstPermanentDeformationWithInfluenceOfRim' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SafetyFactorAgainstPermanentDeformationWithInfluenceOfRim

    @property
    def safety_against_crack_initiation(self) -> 'float':
        '''float: 'SafetyAgainstCrackInitiation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SafetyAgainstCrackInitiation

    @property
    def safety_against_crack_initiation_with_influence_of_rim(self) -> 'float':
        '''float: 'SafetyAgainstCrackInitiationWithInfluenceOfRim' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SafetyAgainstCrackInitiationWithInfluenceOfRim

    @property
    def tangential_force_in_transverse_action(self) -> 'float':
        '''float: 'TangentialForceInTransverseAction' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TangentialForceInTransverseAction

    @property
    def radial_force_in_transverse_action(self) -> 'float':
        '''float: 'RadialForceInTransverseAction' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RadialForceInTransverseAction

    @property
    def size_factor(self) -> 'float':
        '''float: 'SizeFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SizeFactor

    @property
    def notch_sensitivity_factor_for_fatigue_strength(self) -> 'float':
        '''float: 'NotchSensitivityFactorForFatigueStrength' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NotchSensitivityFactorForFatigueStrength

    @property
    def helix_factor(self) -> 'float':
        '''float: 'HelixFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.HelixFactor

    @property
    def overlap_factor(self) -> 'float':
        '''float: 'OverlapFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OverlapFactor

    @property
    def peakto_peak_amplitude_of_local_stress_stiff_rim(self) -> 'float':
        '''float: 'PeaktoPeakAmplitudeOfLocalStressStiffRim' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PeaktoPeakAmplitudeOfLocalStressStiffRim

    @property
    def nominal_stress_due_to_action_of_centrifugal_force(self) -> 'float':
        '''float: 'NominalStressDueToActionOfCentrifugalForce' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NominalStressDueToActionOfCentrifugalForce

    @property
    def local_stress_due_to_action_of_centrifugal_force(self) -> 'float':
        '''float: 'LocalStressDueToActionOfCentrifugalForce' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LocalStressDueToActionOfCentrifugalForce

    @property
    def tip_factor(self) -> 'float':
        '''float: 'TipFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TipFactor

    @property
    def stress_concentration_factor(self) -> 'float':
        '''float: 'StressConcentrationFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StressConcentrationFactor

    @property
    def form_factor_bending(self) -> 'float':
        '''float: 'FormFactorBending' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FormFactorBending

    @property
    def form_factor_for_compression(self) -> 'float':
        '''float: 'FormFactorForCompression' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FormFactorForCompression

    @property
    def factor_of_loading_zone_of_tooth_contact_fatigue_fracture(self) -> 'float':
        '''float: 'FactorOfLoadingZoneOfToothContactFatigueFracture' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FactorOfLoadingZoneOfToothContactFatigueFracture

    @property
    def stress_concentration_factor_due_to_tensile_stress_in_gear_rim(self) -> 'float':
        '''float: 'StressConcentrationFactorDueToTensileStressInGearRim' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StressConcentrationFactorDueToTensileStressInGearRim

    @property
    def tensile_yield_strength_exceeded(self) -> 'bool':
        '''bool: 'TensileYieldStrengthExceeded' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TensileYieldStrengthExceeded

    @property
    def fatigue_strength(self) -> 'float':
        '''float: 'FatigueStrength' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FatigueStrength

    @property
    def mean_stress_component_2(self) -> 'float':
        '''float: 'MeanStressComponent2' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanStressComponent2

    @property
    def reversed_fatigue_strength_of_tooth_root(self) -> 'float':
        '''float: 'ReversedFatigueStrengthOfToothRoot' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ReversedFatigueStrengthOfToothRoot

    @property
    def peakto_peak_amplitude_of_local_stress_compression(self) -> 'float':
        '''float: 'PeaktoPeakAmplitudeOfLocalStressCompression' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PeaktoPeakAmplitudeOfLocalStressCompression

    @property
    def local_stress_due_to_the_rim_bending_moment_outside_of_the_zone_of_tooth_contact(self) -> 'float':
        '''float: 'LocalStressDueToTheRimBendingMomentOutsideOfTheZoneOfToothContact' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LocalStressDueToTheRimBendingMomentOutsideOfTheZoneOfToothContact

    @property
    def peakto_peak_amplitude_of_local_stress(self) -> 'float':
        '''float: 'PeaktoPeakAmplitudeOfLocalStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PeaktoPeakAmplitudeOfLocalStress

    @property
    def stress_concentration_factor_due_to_compression_by_radial_force(self) -> 'float':
        '''float: 'StressConcentrationFactorDueToCompressionByRadialForce' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StressConcentrationFactorDueToCompressionByRadialForce

    @property
    def position_of_maximum_local_stress(self) -> 'float':
        '''float: 'PositionOfMaximumLocalStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PositionOfMaximumLocalStress

    @property
    def position_of_maximum_local_stress_due_to_tangential_force(self) -> 'float':
        '''float: 'PositionOfMaximumLocalStressDueToTangentialForce' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PositionOfMaximumLocalStressDueToTangentialForce

    @property
    def position_of_maximum_local_stress_due_to_bending_moment(self) -> 'float':
        '''float: 'PositionOfMaximumLocalStressDueToBendingMoment' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PositionOfMaximumLocalStressDueToBendingMoment

    @property
    def stress_concentration_factor_due_to_tangential_force(self) -> 'float':
        '''float: 'StressConcentrationFactorDueToTangentialForce' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StressConcentrationFactorDueToTangentialForce

    @property
    def stress_concentration_factor_due_to_bending_moment(self) -> 'float':
        '''float: 'StressConcentrationFactorDueToBendingMoment' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StressConcentrationFactorDueToBendingMoment

    @property
    def level_of_force_application(self) -> 'float':
        '''float: 'LevelOfForceApplication' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LevelOfForceApplication

    @property
    def mean_stress_component_compression(self) -> 'float':
        '''float: 'MeanStressComponentCompression' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanStressComponentCompression

    @property
    def maximum_fatigue_strength(self) -> 'float':
        '''float: 'MaximumFatigueStrength' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumFatigueStrength

    @property
    def number_of_planets(self) -> 'int':
        '''int: 'NumberOfPlanets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NumberOfPlanets

    @property
    def fatigue_strength_with_influence_of_rim(self) -> 'float':
        '''float: 'FatigueStrengthWithInfluenceOfRim' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FatigueStrengthWithInfluenceOfRim

    @property
    def name(self) -> 'str':
        '''str: 'Name' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Name

    @property
    def one_and_a_half_times_normal_module(self) -> 'float':
        '''float: 'OneAndAHalfTimesNormalModule' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OneAndAHalfTimesNormalModule

    @property
    def iso_gear_rating(self) -> '_478.ISO6336AbstractMetalGearSingleFlankRating':
        '''ISO6336AbstractMetalGearSingleFlankRating: 'ISOGearRating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _478.ISO6336AbstractMetalGearSingleFlankRating.TYPE not in self.wrapped.ISOGearRating.__class__.__mro__:
            raise CastException('Failed to cast iso_gear_rating to ISO6336AbstractMetalGearSingleFlankRating. Expected: {}.'.format(self.wrapped.ISOGearRating.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ISOGearRating.__class__)(self.wrapped.ISOGearRating) if self.wrapped.ISOGearRating else None

    @property
    def iso_gear_rating_of_type_iso63361996_gear_single_flank_rating(self) -> '_470.ISO63361996GearSingleFlankRating':
        '''ISO63361996GearSingleFlankRating: 'ISOGearRating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _470.ISO63361996GearSingleFlankRating.TYPE not in self.wrapped.ISOGearRating.__class__.__mro__:
            raise CastException('Failed to cast iso_gear_rating to ISO63361996GearSingleFlankRating. Expected: {}.'.format(self.wrapped.ISOGearRating.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ISOGearRating.__class__)(self.wrapped.ISOGearRating) if self.wrapped.ISOGearRating else None

    @property
    def iso_gear_rating_of_type_iso63362006_gear_single_flank_rating(self) -> '_472.ISO63362006GearSingleFlankRating':
        '''ISO63362006GearSingleFlankRating: 'ISOGearRating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _472.ISO63362006GearSingleFlankRating.TYPE not in self.wrapped.ISOGearRating.__class__.__mro__:
            raise CastException('Failed to cast iso_gear_rating to ISO63362006GearSingleFlankRating. Expected: {}.'.format(self.wrapped.ISOGearRating.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ISOGearRating.__class__)(self.wrapped.ISOGearRating) if self.wrapped.ISOGearRating else None

    @property
    def iso_gear_rating_of_type_iso63362019_gear_single_flank_rating(self) -> '_474.ISO63362019GearSingleFlankRating':
        '''ISO63362019GearSingleFlankRating: 'ISOGearRating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _474.ISO63362019GearSingleFlankRating.TYPE not in self.wrapped.ISOGearRating.__class__.__mro__:
            raise CastException('Failed to cast iso_gear_rating to ISO63362019GearSingleFlankRating. Expected: {}.'.format(self.wrapped.ISOGearRating.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ISOGearRating.__class__)(self.wrapped.ISOGearRating) if self.wrapped.ISOGearRating else None

    @property
    def iso_gear_rating_of_type_din3990_gear_single_flank_rating(self) -> '_485.DIN3990GearSingleFlankRating':
        '''DIN3990GearSingleFlankRating: 'ISOGearRating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _485.DIN3990GearSingleFlankRating.TYPE not in self.wrapped.ISOGearRating.__class__.__mro__:
            raise CastException('Failed to cast iso_gear_rating to DIN3990GearSingleFlankRating. Expected: {}.'.format(self.wrapped.ISOGearRating.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ISOGearRating.__class__)(self.wrapped.ISOGearRating) if self.wrapped.ISOGearRating else None



'''_1.py

Initialiser
'''


from mastapy._internal import constructor
from mastapy._internal.python_net import python_net_import

_INITIALISER = python_net_import('SMT.MastaAPI', 'Initialiser')


__docformat__ = 'restructuredtext en'
__all__ = ('Initialiser',)


class Initialiser:
    '''Initialiser

    This is a mastapy class.
    '''

    TYPE = _INITIALISER

    __hash__ = None

    def __init__(self, instance_to_wrap: 'Initialiser.TYPE'):
        self.wrapped = instance_to_wrap
        self._freeze()

    __frozen = False

    def __setattr__(self, attr, value):
        prop = getattr(self.__class__, attr, None)
        if isinstance(prop, property):
            prop.fset(self, value)
        else:
            if self.__frozen and attr not in self.__dict__:
                raise AttributeError((
                    'Attempted to set unknown '
                    'attribute: \'{}\''.format(attr))) from None

            super().__setattr__(attr, value)

    def __delattr__(self, name):
        raise AttributeError(
            'Cannot delete the attributes of a mastapy object.') from None

    def _freeze(self):
        self.__frozen = True

    def initialise_api_access(self, installation_directory: 'str'):
        ''' 'InitialiseApiAccess' is the original name of this method.

        Args:
            installation_directory (str)
        '''

        installation_directory = str(installation_directory)
        self.wrapped.InitialiseApiAccess(installation_directory if installation_directory else None)



'''_6527.py

ConicalGearMeshLoadCase
'''


from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy._internal import constructor
from mastapy.system_model.connections_and_sockets.gears import (
    _2016, _2008, _2010, _2012,
    _2024, _2027, _2028, _2029,
    _2032, _2034, _2036, _2040
)
from mastapy._internal.cast_exception import CastException
from mastapy.gears.gear_designs.conical import _1095, _1089
from mastapy.system_model.analyses_and_results.static_loads import _6528, _6574
from mastapy._internal.python_net import python_net_import

_CONICAL_GEAR_MESH_LOAD_CASE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads', 'ConicalGearMeshLoadCase')


__docformat__ = 'restructuredtext en'
__all__ = ('ConicalGearMeshLoadCase',)


class ConicalGearMeshLoadCase(_6574.GearMeshLoadCase):
    '''ConicalGearMeshLoadCase

    This is a mastapy class.
    '''

    TYPE = _CONICAL_GEAR_MESH_LOAD_CASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConicalGearMeshLoadCase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def crowning(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'Crowning' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.Crowning) if self.wrapped.Crowning else None

    @crowning.setter
    def crowning(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.Crowning = value

    @property
    def use_gleason_gems_data_for_efficiency(self) -> 'bool':
        '''bool: 'UseGleasonGEMSDataForEfficiency' is the original name of this property.'''

        return self.wrapped.UseGleasonGEMSDataForEfficiency

    @use_gleason_gems_data_for_efficiency.setter
    def use_gleason_gems_data_for_efficiency(self, value: 'bool'):
        self.wrapped.UseGleasonGEMSDataForEfficiency = bool(value) if value else False

    @property
    def use_ki_mo_s_data_for_efficiency(self) -> 'bool':
        '''bool: 'UseKIMoSDataForEfficiency' is the original name of this property.'''

        return self.wrapped.UseKIMoSDataForEfficiency

    @use_ki_mo_s_data_for_efficiency.setter
    def use_ki_mo_s_data_for_efficiency(self, value: 'bool'):
        self.wrapped.UseKIMoSDataForEfficiency = bool(value) if value else False

    @property
    def use_user_specified_misalignments_in_tca(self) -> 'bool':
        '''bool: 'UseUserSpecifiedMisalignmentsInTCA' is the original name of this property.'''

        return self.wrapped.UseUserSpecifiedMisalignmentsInTCA

    @use_user_specified_misalignments_in_tca.setter
    def use_user_specified_misalignments_in_tca(self, value: 'bool'):
        self.wrapped.UseUserSpecifiedMisalignmentsInTCA = bool(value) if value else False

    @property
    def connection_design(self) -> '_2016.ConicalGearMesh':
        '''ConicalGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2016.ConicalGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to ConicalGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_agma_gleason_conical_gear_mesh(self) -> '_2008.AGMAGleasonConicalGearMesh':
        '''AGMAGleasonConicalGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2008.AGMAGleasonConicalGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to AGMAGleasonConicalGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_bevel_differential_gear_mesh(self) -> '_2010.BevelDifferentialGearMesh':
        '''BevelDifferentialGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2010.BevelDifferentialGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to BevelDifferentialGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_bevel_gear_mesh(self) -> '_2012.BevelGearMesh':
        '''BevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2012.BevelGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to BevelGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_hypoid_gear_mesh(self) -> '_2024.HypoidGearMesh':
        '''HypoidGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2024.HypoidGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to HypoidGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_klingelnberg_cyclo_palloid_conical_gear_mesh(self) -> '_2027.KlingelnbergCycloPalloidConicalGearMesh':
        '''KlingelnbergCycloPalloidConicalGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2027.KlingelnbergCycloPalloidConicalGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to KlingelnbergCycloPalloidConicalGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_klingelnberg_cyclo_palloid_hypoid_gear_mesh(self) -> '_2028.KlingelnbergCycloPalloidHypoidGearMesh':
        '''KlingelnbergCycloPalloidHypoidGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2028.KlingelnbergCycloPalloidHypoidGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to KlingelnbergCycloPalloidHypoidGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh(self) -> '_2029.KlingelnbergCycloPalloidSpiralBevelGearMesh':
        '''KlingelnbergCycloPalloidSpiralBevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2029.KlingelnbergCycloPalloidSpiralBevelGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to KlingelnbergCycloPalloidSpiralBevelGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_spiral_bevel_gear_mesh(self) -> '_2032.SpiralBevelGearMesh':
        '''SpiralBevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2032.SpiralBevelGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to SpiralBevelGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_straight_bevel_diff_gear_mesh(self) -> '_2034.StraightBevelDiffGearMesh':
        '''StraightBevelDiffGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2034.StraightBevelDiffGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to StraightBevelDiffGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_straight_bevel_gear_mesh(self) -> '_2036.StraightBevelGearMesh':
        '''StraightBevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2036.StraightBevelGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to StraightBevelGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_zerol_bevel_gear_mesh(self) -> '_2040.ZerolBevelGearMesh':
        '''ZerolBevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2040.ZerolBevelGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to ZerolBevelGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def results_from_imported_xml(self) -> '_1095.KimosBevelHypoidSingleLoadCaseResultsData':
        '''KimosBevelHypoidSingleLoadCaseResultsData: 'ResultsFromImportedXML' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1095.KimosBevelHypoidSingleLoadCaseResultsData)(self.wrapped.ResultsFromImportedXML) if self.wrapped.ResultsFromImportedXML else None

    @property
    def user_specified_misalignments(self) -> '_1089.ConicalMeshMisalignments':
        '''ConicalMeshMisalignments: 'UserSpecifiedMisalignments' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1089.ConicalMeshMisalignments)(self.wrapped.UserSpecifiedMisalignments) if self.wrapped.UserSpecifiedMisalignments else None

    def get_harmonic_load_data_for_import(self) -> '_6528.ConicalGearSetHarmonicLoadData':
        ''' 'GetHarmonicLoadDataForImport' is the original name of this method.

        Returns:
            mastapy.system_model.analyses_and_results.static_loads.ConicalGearSetHarmonicLoadData
        '''

        method_result = self.wrapped.GetHarmonicLoadDataForImport()
        return constructor.new_override(method_result.__class__)(method_result) if method_result else None



'''_938.py

BasicRackProfiles
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_BASIC_RACK_PROFILES = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical', 'BasicRackProfiles')


__docformat__ = 'restructuredtext en'
__all__ = ('BasicRackProfiles',)


class BasicRackProfiles(Enum):
    '''BasicRackProfiles

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _BASIC_RACK_PROFILES

    __hash__ = None

    ISO_53_PROFILE_A = 0
    ISO_53_PROFILE_B = 1
    ISO_53_PROFILE_C = 2
    ISO_53_PROFILE_D = 3
    CUSTOM = 4


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


BasicRackProfiles.__setattr__ = __enum_setattr
BasicRackProfiles.__delattr__ = __enum_delattr



'''_1790.py

RollingBearingFrictionCoefficients
'''


from mastapy._internal import constructor
from mastapy._internal.python_net import python_net_import
from mastapy.bearings.bearing_results import _1670
from mastapy.bearings.bearing_results.rolling import _1697
from mastapy.utility import _1364

_DATABASE_WITH_SELECTED_ITEM = python_net_import('SMT.MastaAPI.UtilityGUI.Databases', 'DatabaseWithSelectedItem')
_ROLLING_BEARING_FRICTION_COEFFICIENTS = python_net_import('SMT.MastaAPI.Bearings.BearingResults.Rolling', 'RollingBearingFrictionCoefficients')


__docformat__ = 'restructuredtext en'
__all__ = ('RollingBearingFrictionCoefficients',)


class RollingBearingFrictionCoefficients(_1364.IndependentReportablePropertiesBase['RollingBearingFrictionCoefficients']):
    '''RollingBearingFrictionCoefficients

    This is a mastapy class.
    '''

    TYPE = _ROLLING_BEARING_FRICTION_COEFFICIENTS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RollingBearingFrictionCoefficients.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def use_user_specified_f0(self) -> 'bool':
        '''bool: 'UseUserSpecifiedF0' is the original name of this property.'''

        return self.wrapped.UseUserSpecifiedF0

    @use_user_specified_f0.setter
    def use_user_specified_f0(self, value: 'bool'):
        self.wrapped.UseUserSpecifiedF0 = bool(value) if value else False

    @property
    def user_specified_f0(self) -> 'float':
        '''float: 'UserSpecifiedF0' is the original name of this property.'''

        return self.wrapped.UserSpecifiedF0

    @user_specified_f0.setter
    def user_specified_f0(self, value: 'float'):
        self.wrapped.UserSpecifiedF0 = float(value) if value else 0.0

    @property
    def use_user_specified_f1_for_din732(self) -> 'bool':
        '''bool: 'UseUserSpecifiedF1ForDIN732' is the original name of this property.'''

        return self.wrapped.UseUserSpecifiedF1ForDIN732

    @use_user_specified_f1_for_din732.setter
    def use_user_specified_f1_for_din732(self, value: 'bool'):
        self.wrapped.UseUserSpecifiedF1ForDIN732 = bool(value) if value else False

    @property
    def user_specified_f1_for_din732(self) -> 'float':
        '''float: 'UserSpecifiedF1ForDIN732' is the original name of this property.'''

        return self.wrapped.UserSpecifiedF1ForDIN732

    @user_specified_f1_for_din732.setter
    def user_specified_f1_for_din732(self, value: 'float'):
        self.wrapped.UserSpecifiedF1ForDIN732 = float(value) if value else 0.0

    @property
    def use_user_specified_f0r(self) -> 'bool':
        '''bool: 'UseUserSpecifiedF0r' is the original name of this property.'''

        return self.wrapped.UseUserSpecifiedF0r

    @use_user_specified_f0r.setter
    def use_user_specified_f0r(self, value: 'bool'):
        self.wrapped.UseUserSpecifiedF0r = bool(value) if value else False

    @property
    def user_specified_f0r(self) -> 'float':
        '''float: 'UserSpecifiedF0r' is the original name of this property.'''

        return self.wrapped.UserSpecifiedF0r

    @user_specified_f0r.setter
    def user_specified_f0r(self, value: 'float'):
        self.wrapped.UserSpecifiedF0r = float(value) if value else 0.0

    @property
    def use_user_specified_f1r(self) -> 'bool':
        '''bool: 'UseUserSpecifiedF1r' is the original name of this property.'''

        return self.wrapped.UseUserSpecifiedF1r

    @use_user_specified_f1r.setter
    def use_user_specified_f1r(self, value: 'bool'):
        self.wrapped.UseUserSpecifiedF1r = bool(value) if value else False

    @property
    def user_specified_f1r(self) -> 'float':
        '''float: 'UserSpecifiedF1r' is the original name of this property.'''

        return self.wrapped.UserSpecifiedF1r

    @user_specified_f1r.setter
    def user_specified_f1r(self, value: 'float'):
        self.wrapped.UserSpecifiedF1r = float(value) if value else 0.0

    @property
    def iso14179_settings_database(self) -> 'str':
        '''str: 'ISO14179SettingsDatabase' is the original name of this property.'''

        return self.wrapped.ISO14179SettingsDatabase.SelectedItemName

    @iso14179_settings_database.setter
    def iso14179_settings_database(self, value: 'str'):
        self.wrapped.ISO14179SettingsDatabase.SetSelectedItem(str(value) if value else None)

    @property
    def iso14179_static_equivalent_load_factors(self) -> '_1670.EquivalentLoadFactors':
        '''EquivalentLoadFactors: 'ISO14179StaticEquivalentLoadFactors' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1670.EquivalentLoadFactors)(self.wrapped.ISO14179StaticEquivalentLoadFactors) if self.wrapped.ISO14179StaticEquivalentLoadFactors else None

    @property
    def iso14179_dynamic_equivalent_load_factors(self) -> '_1670.EquivalentLoadFactors':
        '''EquivalentLoadFactors: 'ISO14179DynamicEquivalentLoadFactors' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1670.EquivalentLoadFactors)(self.wrapped.ISO14179DynamicEquivalentLoadFactors) if self.wrapped.ISO14179DynamicEquivalentLoadFactors else None

    @property
    def iso14179_settings(self) -> '_1697.ISO14179Settings':
        '''ISO14179Settings: 'ISO14179Settings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1697.ISO14179Settings)(self.wrapped.ISO14179Settings) if self.wrapped.ISO14179Settings else None



'''_6619.py

PlanetarySocketManufactureError
'''


from typing import List

from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6621
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_PLANETARY_SOCKET_MANUFACTURE_ERROR = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads', 'PlanetarySocketManufactureError')


__docformat__ = 'restructuredtext en'
__all__ = ('PlanetarySocketManufactureError',)


class PlanetarySocketManufactureError(_0.APIBase):
    '''PlanetarySocketManufactureError

    This is a mastapy class.
    '''

    TYPE = _PLANETARY_SOCKET_MANUFACTURE_ERROR

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PlanetarySocketManufactureError.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def socket_name(self) -> 'str':
        '''str: 'SocketName' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SocketName

    @property
    def planet_manufacture_errors(self) -> 'List[_6621.PlanetManufactureError]':
        '''List[PlanetManufactureError]: 'PlanetManufactureErrors' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.PlanetManufactureErrors, constructor.new(_6621.PlanetManufactureError))
        return value



'''_2287.py

ClutchType
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_CLUTCH_TYPE = python_net_import('SMT.MastaAPI.SystemModel.PartModel.Couplings', 'ClutchType')


__docformat__ = 'restructuredtext en'
__all__ = ('ClutchType',)


class ClutchType(Enum):
    '''ClutchType

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _CLUTCH_TYPE

    __hash__ = None

    CONCEPT_CLUTCH = 0
    MULTIPLATE_CLUTCH = 1


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


ClutchType.__setattr__ = __enum_setattr
ClutchType.__delattr__ = __enum_delattr



'''_7033.py

KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection
'''


from typing import List

from mastapy.system_model.part_model.gears import _2248
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6604
from mastapy.gears.rating.klingelnberg_spiral_bevel import _372
from mastapy.system_model.analyses_and_results.advanced_system_deflections import _7031, _7032, _7027
from mastapy.system_model.analyses_and_results.system_deflections import _2477
from mastapy._internal.python_net import python_net_import

_KLINGELNBERG_CYCLO_PALLOID_SPIRAL_BEVEL_GEAR_SET_ADVANCED_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedSystemDeflections', 'KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection',)


class KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection(_7027.KlingelnbergCycloPalloidConicalGearSetAdvancedSystemDeflection):
    '''KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _KLINGELNBERG_CYCLO_PALLOID_SPIRAL_BEVEL_GEAR_SET_ADVANCED_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2248.KlingelnbergCycloPalloidSpiralBevelGearSet':
        '''KlingelnbergCycloPalloidSpiralBevelGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2248.KlingelnbergCycloPalloidSpiralBevelGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6604.KlingelnbergCycloPalloidSpiralBevelGearSetLoadCase':
        '''KlingelnbergCycloPalloidSpiralBevelGearSetLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6604.KlingelnbergCycloPalloidSpiralBevelGearSetLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def rating(self) -> '_372.KlingelnbergCycloPalloidSpiralBevelGearSetRating':
        '''KlingelnbergCycloPalloidSpiralBevelGearSetRating: 'Rating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_372.KlingelnbergCycloPalloidSpiralBevelGearSetRating)(self.wrapped.Rating) if self.wrapped.Rating else None

    @property
    def component_detailed_analysis(self) -> '_372.KlingelnbergCycloPalloidSpiralBevelGearSetRating':
        '''KlingelnbergCycloPalloidSpiralBevelGearSetRating: 'ComponentDetailedAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_372.KlingelnbergCycloPalloidSpiralBevelGearSetRating)(self.wrapped.ComponentDetailedAnalysis) if self.wrapped.ComponentDetailedAnalysis else None

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gears_advanced_system_deflection(self) -> 'List[_7031.KlingelnbergCycloPalloidSpiralBevelGearAdvancedSystemDeflection]':
        '''List[KlingelnbergCycloPalloidSpiralBevelGearAdvancedSystemDeflection]: 'KlingelnbergCycloPalloidSpiralBevelGearsAdvancedSystemDeflection' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidSpiralBevelGearsAdvancedSystemDeflection, constructor.new(_7031.KlingelnbergCycloPalloidSpiralBevelGearAdvancedSystemDeflection))
        return value

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_meshes_advanced_system_deflection(self) -> 'List[_7032.KlingelnbergCycloPalloidSpiralBevelGearMeshAdvancedSystemDeflection]':
        '''List[KlingelnbergCycloPalloidSpiralBevelGearMeshAdvancedSystemDeflection]: 'KlingelnbergCycloPalloidSpiralBevelMeshesAdvancedSystemDeflection' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidSpiralBevelMeshesAdvancedSystemDeflection, constructor.new(_7032.KlingelnbergCycloPalloidSpiralBevelGearMeshAdvancedSystemDeflection))
        return value

    @property
    def assembly_system_deflection_results(self) -> 'List[_2477.KlingelnbergCycloPalloidSpiralBevelGearSetSystemDeflection]':
        '''List[KlingelnbergCycloPalloidSpiralBevelGearSetSystemDeflection]: 'AssemblySystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblySystemDeflectionResults, constructor.new(_2477.KlingelnbergCycloPalloidSpiralBevelGearSetSystemDeflection))
        return value



'''_2260.py

ZerolBevelGear
'''


from mastapy.gears.gear_designs.zerol_bevel import _890
from mastapy._internal import constructor
from mastapy.system_model.part_model.gears import _2226
from mastapy._internal.python_net import python_net_import

_ZEROL_BEVEL_GEAR = python_net_import('SMT.MastaAPI.SystemModel.PartModel.Gears', 'ZerolBevelGear')


__docformat__ = 'restructuredtext en'
__all__ = ('ZerolBevelGear',)


class ZerolBevelGear(_2226.BevelGear):
    '''ZerolBevelGear

    This is a mastapy class.
    '''

    TYPE = _ZEROL_BEVEL_GEAR

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ZerolBevelGear.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def bevel_gear_design(self) -> '_890.ZerolBevelGearDesign':
        '''ZerolBevelGearDesign: 'BevelGearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_890.ZerolBevelGearDesign)(self.wrapped.BevelGearDesign) if self.wrapped.BevelGearDesign else None

    @property
    def zerol_bevel_gear_design(self) -> '_890.ZerolBevelGearDesign':
        '''ZerolBevelGearDesign: 'ZerolBevelGearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_890.ZerolBevelGearDesign)(self.wrapped.ZerolBevelGearDesign) if self.wrapped.ZerolBevelGearDesign else None



'''_707.py

PlungeShaverDynamics
'''


from mastapy._internal import constructor
from mastapy.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics import _717
from mastapy._internal.python_net import python_net_import

_PLUNGE_SHAVER_DYNAMICS = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical.AxialAndPlungeShavingDynamics', 'PlungeShaverDynamics')


__docformat__ = 'restructuredtext en'
__all__ = ('PlungeShaverDynamics',)


class PlungeShaverDynamics(_717.ShavingDynamics):
    '''PlungeShaverDynamics

    This is a mastapy class.
    '''

    TYPE = _PLUNGE_SHAVER_DYNAMICS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PlungeShaverDynamics.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def number_of_gear_teeth_passed_per_flank(self) -> 'float':
        '''float: 'NumberOfGearTeethPassedPerFlank' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NumberOfGearTeethPassedPerFlank



'''_2697.py

BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft
'''


from typing import List

from mastapy.system_model.part_model.gears import _2223
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6506
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import _2698, _2696, _2702
from mastapy._internal.python_net import python_net_import

_BEVEL_DIFFERENTIAL_GEAR_SET_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesOnAShaft', 'BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft')


__docformat__ = 'restructuredtext en'
__all__ = ('BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft',)


class BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft(_2702.BevelGearSetSteadyStateSynchronousResponseOnAShaft):
    '''BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft

    This is a mastapy class.
    '''

    TYPE = _BEVEL_DIFFERENTIAL_GEAR_SET_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2223.BevelDifferentialGearSet':
        '''BevelDifferentialGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2223.BevelDifferentialGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6506.BevelDifferentialGearSetLoadCase':
        '''BevelDifferentialGearSetLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6506.BevelDifferentialGearSetLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def bevel_differential_gears_steady_state_synchronous_response_on_a_shaft(self) -> 'List[_2698.BevelDifferentialGearSteadyStateSynchronousResponseOnAShaft]':
        '''List[BevelDifferentialGearSteadyStateSynchronousResponseOnAShaft]: 'BevelDifferentialGearsSteadyStateSynchronousResponseOnAShaft' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BevelDifferentialGearsSteadyStateSynchronousResponseOnAShaft, constructor.new(_2698.BevelDifferentialGearSteadyStateSynchronousResponseOnAShaft))
        return value

    @property
    def bevel_differential_meshes_steady_state_synchronous_response_on_a_shaft(self) -> 'List[_2696.BevelDifferentialGearMeshSteadyStateSynchronousResponseOnAShaft]':
        '''List[BevelDifferentialGearMeshSteadyStateSynchronousResponseOnAShaft]: 'BevelDifferentialMeshesSteadyStateSynchronousResponseOnAShaft' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BevelDifferentialMeshesSteadyStateSynchronousResponseOnAShaft, constructor.new(_2696.BevelDifferentialGearMeshSteadyStateSynchronousResponseOnAShaft))
        return value



'''_389.py

Iso10300MeshSingleFlankRatingHypoidMethodB2
'''


from mastapy._internal import constructor
from mastapy.gears.rating.iso_10300 import _391
from mastapy._internal.python_net import python_net_import

_ISO_10300_MESH_SINGLE_FLANK_RATING_HYPOID_METHOD_B2 = python_net_import('SMT.MastaAPI.Gears.Rating.Iso10300', 'Iso10300MeshSingleFlankRatingHypoidMethodB2')


__docformat__ = 'restructuredtext en'
__all__ = ('Iso10300MeshSingleFlankRatingHypoidMethodB2',)


class Iso10300MeshSingleFlankRatingHypoidMethodB2(_391.ISO10300MeshSingleFlankRatingMethodB2):
    '''Iso10300MeshSingleFlankRatingHypoidMethodB2

    This is a mastapy class.
    '''

    TYPE = _ISO_10300_MESH_SINGLE_FLANK_RATING_HYPOID_METHOD_B2

    __hash__ = None

    def __init__(self, instance_to_wrap: 'Iso10300MeshSingleFlankRatingHypoidMethodB2.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def profile_load_sharing_factor(self) -> 'float':
        '''float: 'ProfileLoadSharingFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ProfileLoadSharingFactor

    @property
    def lengthwise_load_sharing_factor(self) -> 'float':
        '''float: 'LengthwiseLoadSharingFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LengthwiseLoadSharingFactor

    @property
    def length_of_action_from_pinion_tip_to_point_of_load_application(self) -> 'float':
        '''float: 'LengthOfActionFromPinionTipToPointOfLoadApplication' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LengthOfActionFromPinionTipToPointOfLoadApplication

    @property
    def length_of_action_from_wheel_tip_to_point_of_load_application(self) -> 'float':
        '''float: 'LengthOfActionFromWheelTipToPointOfLoadApplication' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LengthOfActionFromWheelTipToPointOfLoadApplication

    @property
    def pinion_length_of_action_point_of_load_application(self) -> 'float':
        '''float: 'PinionLengthOfActionPointOfLoadApplication' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionLengthOfActionPointOfLoadApplication

    @property
    def wheel_length_of_action_point_of_load_application(self) -> 'float':
        '''float: 'WheelLengthOfActionPointOfLoadApplication' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelLengthOfActionPointOfLoadApplication



'''_3396.py

GearSetCompoundSteadyStateSynchronousResponse
'''


from typing import List

from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses import _3263
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses.compound import _3434
from mastapy._internal.python_net import python_net_import

_GEAR_SET_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponses.Compound', 'GearSetCompoundSteadyStateSynchronousResponse')


__docformat__ = 'restructuredtext en'
__all__ = ('GearSetCompoundSteadyStateSynchronousResponse',)


class GearSetCompoundSteadyStateSynchronousResponse(_3434.SpecialisedAssemblyCompoundSteadyStateSynchronousResponse):
    '''GearSetCompoundSteadyStateSynchronousResponse

    This is a mastapy class.
    '''

    TYPE = _GEAR_SET_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GearSetCompoundSteadyStateSynchronousResponse.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_analysis_cases(self) -> 'List[_3263.GearSetSteadyStateSynchronousResponse]':
        '''List[GearSetSteadyStateSynchronousResponse]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCases, constructor.new(_3263.GearSetSteadyStateSynchronousResponse))
        return value

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_3263.GearSetSteadyStateSynchronousResponse]':
        '''List[GearSetSteadyStateSynchronousResponse]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCasesReady, constructor.new(_3263.GearSetSteadyStateSynchronousResponse))
        return value



'''_758.py

PinionFinishMachineSettings
'''


from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy.gears.gear_designs.conical import _1100
from mastapy.gears import _285
from mastapy._internal.python_net import python_net_import

_PINION_FINISH_MACHINE_SETTINGS = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Bevel', 'PinionFinishMachineSettings')


__docformat__ = 'restructuredtext en'
__all__ = ('PinionFinishMachineSettings',)


class PinionFinishMachineSettings(_285.ConicalGearToothSurface):
    '''PinionFinishMachineSettings

    This is a mastapy class.
    '''

    TYPE = _PINION_FINISH_MACHINE_SETTINGS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PinionFinishMachineSettings.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def cutter_radius(self) -> 'float':
        '''float: 'CutterRadius' is the original name of this property.'''

        return self.wrapped.CutterRadius

    @cutter_radius.setter
    def cutter_radius(self, value: 'float'):
        self.wrapped.CutterRadius = float(value) if value else 0.0

    @property
    def pinion_cutter_blade_angle(self) -> 'float':
        '''float: 'PinionCutterBladeAngle' is the original name of this property.'''

        return self.wrapped.PinionCutterBladeAngle

    @pinion_cutter_blade_angle.setter
    def pinion_cutter_blade_angle(self, value: 'float'):
        self.wrapped.PinionCutterBladeAngle = float(value) if value else 0.0

    @property
    def blade_edge_radius(self) -> 'float':
        '''float: 'BladeEdgeRadius' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BladeEdgeRadius

    @property
    def toprem_letter(self) -> '_1100.TopremLetter':
        '''TopremLetter: 'TopremLetter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_enum(self.wrapped.TopremLetter)
        return constructor.new(_1100.TopremLetter)(value) if value else None

    @property
    def toprem_angle(self) -> 'float':
        '''float: 'TopremAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TopremAngle

    @property
    def toprem_length(self) -> 'float':
        '''float: 'TopremLength' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TopremLength

    @property
    def cc_angle(self) -> 'float':
        '''float: 'CCAngle' is the original name of this property.'''

        return self.wrapped.CCAngle

    @cc_angle.setter
    def cc_angle(self, value: 'float'):
        self.wrapped.CCAngle = float(value) if value else 0.0

    @property
    def ease_off_at_toe_root(self) -> 'float':
        '''float: 'EaseOffAtToeRoot' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EaseOffAtToeRoot

    @property
    def ease_off_at_toe_tip(self) -> 'float':
        '''float: 'EaseOffAtToeTip' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EaseOffAtToeTip

    @property
    def ease_off_at_heel_root(self) -> 'float':
        '''float: 'EaseOffAtHeelRoot' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EaseOffAtHeelRoot

    @property
    def ease_off_at_heel_tip(self) -> 'float':
        '''float: 'EaseOffAtHeelTip' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EaseOffAtHeelTip



'''_5078.py

BearingMultibodyDynamicsAnalysis
'''


from typing import List

from mastapy._internal import constructor, conversion
from mastapy._math.vector_3d import Vector3D
from mastapy.system_model.part_model import _2149
from mastapy.system_model.analyses_and_results.static_loads import _6501
from mastapy.system_model.analyses_and_results.mbd_analyses.reporting import _5217
from mastapy.system_model.analyses_and_results.mbd_analyses import _5108
from mastapy._internal.python_net import python_net_import

_BEARING_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses', 'BearingMultibodyDynamicsAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('BearingMultibodyDynamicsAnalysis',)


class BearingMultibodyDynamicsAnalysis(_5108.ConnectorMultibodyDynamicsAnalysis):
    '''BearingMultibodyDynamicsAnalysis

    This is a mastapy class.
    '''

    TYPE = _BEARING_MULTIBODY_DYNAMICS_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BearingMultibodyDynamicsAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def iso2812007_basic_rating_life_damage_rate(self) -> 'float':
        '''float: 'ISO2812007BasicRatingLifeDamageRate' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ISO2812007BasicRatingLifeDamageRate

    @property
    def iso2812007_basic_rating_life_damage_during_analysis(self) -> 'float':
        '''float: 'ISO2812007BasicRatingLifeDamageDuringAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ISO2812007BasicRatingLifeDamageDuringAnalysis

    @property
    def iso2812007_modified_rating_life_damage_rate(self) -> 'float':
        '''float: 'ISO2812007ModifiedRatingLifeDamageRate' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ISO2812007ModifiedRatingLifeDamageRate

    @property
    def iso2812007_modified_rating_life_damage_during_analysis(self) -> 'float':
        '''float: 'ISO2812007ModifiedRatingLifeDamageDuringAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ISO2812007ModifiedRatingLifeDamageDuringAnalysis

    @property
    def isots162812008_basic_reference_rating_life_damage_rate(self) -> 'float':
        '''float: 'ISOTS162812008BasicReferenceRatingLifeDamageRate' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ISOTS162812008BasicReferenceRatingLifeDamageRate

    @property
    def isots162812008_basic_reference_rating_life_damage_during_analysis(self) -> 'float':
        '''float: 'ISOTS162812008BasicReferenceRatingLifeDamageDuringAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ISOTS162812008BasicReferenceRatingLifeDamageDuringAnalysis

    @property
    def isots162812008_modified_reference_rating_life_damage_rate(self) -> 'float':
        '''float: 'ISOTS162812008ModifiedReferenceRatingLifeDamageRate' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ISOTS162812008ModifiedReferenceRatingLifeDamageRate

    @property
    def isots162812008_modified_reference_rating_life_damage_during_analysis(self) -> 'float':
        '''float: 'ISOTS162812008ModifiedReferenceRatingLifeDamageDuringAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ISOTS162812008ModifiedReferenceRatingLifeDamageDuringAnalysis

    @property
    def iso762006_safety_factor_at_current_time(self) -> 'float':
        '''float: 'ISO762006SafetyFactorAtCurrentTime' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ISO762006SafetyFactorAtCurrentTime

    @property
    def iso762006_safety_factor(self) -> 'float':
        '''float: 'ISO762006SafetyFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ISO762006SafetyFactor

    @property
    def ansiabma_static_safety_factor_at_current_time(self) -> 'float':
        '''float: 'ANSIABMAStaticSafetyFactorAtCurrentTime' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ANSIABMAStaticSafetyFactorAtCurrentTime

    @property
    def ansiabma_static_safety_factor(self) -> 'float':
        '''float: 'ANSIABMAStaticSafetyFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ANSIABMAStaticSafetyFactor

    @property
    def ansiabma_basic_rating_life_damage_rate(self) -> 'float':
        '''float: 'ANSIABMABasicRatingLifeDamageRate' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ANSIABMABasicRatingLifeDamageRate

    @property
    def ansiabma_basic_rating_life_damage_rate_during_analysis(self) -> 'float':
        '''float: 'ANSIABMABasicRatingLifeDamageRateDuringAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ANSIABMABasicRatingLifeDamageRateDuringAnalysis

    @property
    def ansiabma_adjusted_rating_life_damage_rate(self) -> 'float':
        '''float: 'ANSIABMAAdjustedRatingLifeDamageRate' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ANSIABMAAdjustedRatingLifeDamageRate

    @property
    def ansiabma_adjusted_rating_life_damage_rate_during_analysis(self) -> 'float':
        '''float: 'ANSIABMAAdjustedRatingLifeDamageRateDuringAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ANSIABMAAdjustedRatingLifeDamageRateDuringAnalysis

    @property
    def maximum_static_contact_stress_inner_safety_factor_at_current_time(self) -> 'float':
        '''float: 'MaximumStaticContactStressInnerSafetyFactorAtCurrentTime' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumStaticContactStressInnerSafetyFactorAtCurrentTime

    @property
    def maximum_static_contact_stress_inner_safety_factor(self) -> 'float':
        '''float: 'MaximumStaticContactStressInnerSafetyFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumStaticContactStressInnerSafetyFactor

    @property
    def maximum_element_normal_stress_outer_at_current_time(self) -> 'float':
        '''float: 'MaximumElementNormalStressOuterAtCurrentTime' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumElementNormalStressOuterAtCurrentTime

    @property
    def maximum_element_normal_stress_outer(self) -> 'float':
        '''float: 'MaximumElementNormalStressOuter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumElementNormalStressOuter

    @property
    def maximum_element_normal_stress_inner_at_current_time(self) -> 'float':
        '''float: 'MaximumElementNormalStressInnerAtCurrentTime' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumElementNormalStressInnerAtCurrentTime

    @property
    def maximum_element_normal_stress_inner(self) -> 'float':
        '''float: 'MaximumElementNormalStressInner' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumElementNormalStressInner

    @property
    def maximum_static_contact_stress_outer_safety_factor_at_current_time(self) -> 'float':
        '''float: 'MaximumStaticContactStressOuterSafetyFactorAtCurrentTime' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumStaticContactStressOuterSafetyFactorAtCurrentTime

    @property
    def maximum_static_contact_stress_outer_safety_factor(self) -> 'float':
        '''float: 'MaximumStaticContactStressOuterSafetyFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumStaticContactStressOuterSafetyFactor

    @property
    def relative_displacement(self) -> 'Vector3D':
        '''Vector3D: 'RelativeDisplacement' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_vector3d(self.wrapped.RelativeDisplacement)
        return value

    @property
    def relative_tilt(self) -> 'Vector3D':
        '''Vector3D: 'RelativeTilt' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_vector3d(self.wrapped.RelativeTilt)
        return value

    @property
    def relative_velocity(self) -> 'Vector3D':
        '''Vector3D: 'RelativeVelocity' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_vector3d(self.wrapped.RelativeVelocity)
        return value

    @property
    def relative_acceleration(self) -> 'Vector3D':
        '''Vector3D: 'RelativeAcceleration' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_vector3d(self.wrapped.RelativeAcceleration)
        return value

    @property
    def force(self) -> 'Vector3D':
        '''Vector3D: 'Force' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_vector3d(self.wrapped.Force)
        return value

    @property
    def force_angular(self) -> 'Vector3D':
        '''Vector3D: 'ForceAngular' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_vector3d(self.wrapped.ForceAngular)
        return value

    @property
    def component_design(self) -> '_2149.Bearing':
        '''Bearing: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2149.Bearing)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6501.BearingLoadCase':
        '''BearingLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6501.BearingLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None

    @property
    def peak_dynamic_force(self) -> '_5217.DynamicForceVector3DResult':
        '''DynamicForceVector3DResult: 'PeakDynamicForce' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_5217.DynamicForceVector3DResult)(self.wrapped.PeakDynamicForce) if self.wrapped.PeakDynamicForce else None

    @property
    def planetaries(self) -> 'List[BearingMultibodyDynamicsAnalysis]':
        '''List[BearingMultibodyDynamicsAnalysis]: 'Planetaries' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Planetaries, constructor.new(BearingMultibodyDynamicsAnalysis))
        return value



'''_6591.py

HypoidGearSetLoadCase
'''


from typing import List

from mastapy.system_model.part_model.gears import _2242
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6589, _6590, _6497
from mastapy._internal.python_net import python_net_import

_HYPOID_GEAR_SET_LOAD_CASE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads', 'HypoidGearSetLoadCase')


__docformat__ = 'restructuredtext en'
__all__ = ('HypoidGearSetLoadCase',)


class HypoidGearSetLoadCase(_6497.AGMAGleasonConicalGearSetLoadCase):
    '''HypoidGearSetLoadCase

    This is a mastapy class.
    '''

    TYPE = _HYPOID_GEAR_SET_LOAD_CASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'HypoidGearSetLoadCase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2242.HypoidGearSet':
        '''HypoidGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2242.HypoidGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def gears(self) -> 'List[_6589.HypoidGearLoadCase]':
        '''List[HypoidGearLoadCase]: 'Gears' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Gears, constructor.new(_6589.HypoidGearLoadCase))
        return value

    @property
    def hypoid_gears_load_case(self) -> 'List[_6589.HypoidGearLoadCase]':
        '''List[HypoidGearLoadCase]: 'HypoidGearsLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.HypoidGearsLoadCase, constructor.new(_6589.HypoidGearLoadCase))
        return value

    @property
    def hypoid_meshes_load_case(self) -> 'List[_6590.HypoidGearMeshLoadCase]':
        '''List[HypoidGearMeshLoadCase]: 'HypoidMeshesLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.HypoidMeshesLoadCase, constructor.new(_6590.HypoidGearMeshLoadCase))
        return value



'''_60.py

FEModalFrequencyComparison
'''


from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_FE_MODAL_FREQUENCY_COMPARISON = python_net_import('SMT.MastaAPI.NodalAnalysis', 'FEModalFrequencyComparison')


__docformat__ = 'restructuredtext en'
__all__ = ('FEModalFrequencyComparison',)


class FEModalFrequencyComparison(_0.APIBase):
    '''FEModalFrequencyComparison

    This is a mastapy class.
    '''

    TYPE = _FE_MODAL_FREQUENCY_COMPARISON

    __hash__ = None

    def __init__(self, instance_to_wrap: 'FEModalFrequencyComparison.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def mode(self) -> 'int':
        '''int: 'Mode' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Mode

    @property
    def reduced_model_frequency(self) -> 'float':
        '''float: 'ReducedModelFrequency' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ReducedModelFrequency

    @property
    def full_model_frequency(self) -> 'float':
        '''float: 'FullModelFrequency' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FullModelFrequency

    @property
    def difference_in_frequencies(self) -> 'float':
        '''float: 'DifferenceInFrequencies' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DifferenceInFrequencies

    @property
    def percentage_error(self) -> 'float':
        '''float: 'PercentageError' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PercentageError



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._4400 import AbstractAssemblyCompoundModalAnalysisAtAStiffness
    from ._4401 import AbstractShaftCompoundModalAnalysisAtAStiffness
    from ._4402 import AbstractShaftOrHousingCompoundModalAnalysisAtAStiffness
    from ._4403 import AbstractShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness
    from ._4404 import AGMAGleasonConicalGearCompoundModalAnalysisAtAStiffness
    from ._4405 import AGMAGleasonConicalGearMeshCompoundModalAnalysisAtAStiffness
    from ._4406 import AGMAGleasonConicalGearSetCompoundModalAnalysisAtAStiffness
    from ._4407 import AssemblyCompoundModalAnalysisAtAStiffness
    from ._4408 import BearingCompoundModalAnalysisAtAStiffness
    from ._4409 import BeltConnectionCompoundModalAnalysisAtAStiffness
    from ._4410 import BeltDriveCompoundModalAnalysisAtAStiffness
    from ._4411 import BevelDifferentialGearCompoundModalAnalysisAtAStiffness
    from ._4412 import BevelDifferentialGearMeshCompoundModalAnalysisAtAStiffness
    from ._4413 import BevelDifferentialGearSetCompoundModalAnalysisAtAStiffness
    from ._4414 import BevelDifferentialPlanetGearCompoundModalAnalysisAtAStiffness
    from ._4415 import BevelDifferentialSunGearCompoundModalAnalysisAtAStiffness
    from ._4416 import BevelGearCompoundModalAnalysisAtAStiffness
    from ._4417 import BevelGearMeshCompoundModalAnalysisAtAStiffness
    from ._4418 import BevelGearSetCompoundModalAnalysisAtAStiffness
    from ._4419 import BoltCompoundModalAnalysisAtAStiffness
    from ._4420 import BoltedJointCompoundModalAnalysisAtAStiffness
    from ._4421 import ClutchCompoundModalAnalysisAtAStiffness
    from ._4422 import ClutchConnectionCompoundModalAnalysisAtAStiffness
    from ._4423 import ClutchHalfCompoundModalAnalysisAtAStiffness
    from ._4424 import CoaxialConnectionCompoundModalAnalysisAtAStiffness
    from ._4425 import ComponentCompoundModalAnalysisAtAStiffness
    from ._4426 import ConceptCouplingCompoundModalAnalysisAtAStiffness
    from ._4427 import ConceptCouplingConnectionCompoundModalAnalysisAtAStiffness
    from ._4428 import ConceptCouplingHalfCompoundModalAnalysisAtAStiffness
    from ._4429 import ConceptGearCompoundModalAnalysisAtAStiffness
    from ._4430 import ConceptGearMeshCompoundModalAnalysisAtAStiffness
    from ._4431 import ConceptGearSetCompoundModalAnalysisAtAStiffness
    from ._4432 import ConicalGearCompoundModalAnalysisAtAStiffness
    from ._4433 import ConicalGearMeshCompoundModalAnalysisAtAStiffness
    from ._4434 import ConicalGearSetCompoundModalAnalysisAtAStiffness
    from ._4435 import ConnectionCompoundModalAnalysisAtAStiffness
    from ._4436 import ConnectorCompoundModalAnalysisAtAStiffness
    from ._4437 import CouplingCompoundModalAnalysisAtAStiffness
    from ._4438 import CouplingConnectionCompoundModalAnalysisAtAStiffness
    from ._4439 import CouplingHalfCompoundModalAnalysisAtAStiffness
    from ._4440 import CVTBeltConnectionCompoundModalAnalysisAtAStiffness
    from ._4441 import CVTCompoundModalAnalysisAtAStiffness
    from ._4442 import CVTPulleyCompoundModalAnalysisAtAStiffness
    from ._4443 import CycloidalAssemblyCompoundModalAnalysisAtAStiffness
    from ._4444 import CycloidalDiscCentralBearingConnectionCompoundModalAnalysisAtAStiffness
    from ._4445 import CycloidalDiscCompoundModalAnalysisAtAStiffness
    from ._4446 import CycloidalDiscPlanetaryBearingConnectionCompoundModalAnalysisAtAStiffness
    from ._4447 import CylindricalGearCompoundModalAnalysisAtAStiffness
    from ._4448 import CylindricalGearMeshCompoundModalAnalysisAtAStiffness
    from ._4449 import CylindricalGearSetCompoundModalAnalysisAtAStiffness
    from ._4450 import CylindricalPlanetGearCompoundModalAnalysisAtAStiffness
    from ._4451 import DatumCompoundModalAnalysisAtAStiffness
    from ._4452 import ExternalCADModelCompoundModalAnalysisAtAStiffness
    from ._4453 import FaceGearCompoundModalAnalysisAtAStiffness
    from ._4454 import FaceGearMeshCompoundModalAnalysisAtAStiffness
    from ._4455 import FaceGearSetCompoundModalAnalysisAtAStiffness
    from ._4456 import FEPartCompoundModalAnalysisAtAStiffness
    from ._4457 import FlexiblePinAssemblyCompoundModalAnalysisAtAStiffness
    from ._4458 import GearCompoundModalAnalysisAtAStiffness
    from ._4459 import GearMeshCompoundModalAnalysisAtAStiffness
    from ._4460 import GearSetCompoundModalAnalysisAtAStiffness
    from ._4461 import GuideDxfModelCompoundModalAnalysisAtAStiffness
    from ._4462 import HypoidGearCompoundModalAnalysisAtAStiffness
    from ._4463 import HypoidGearMeshCompoundModalAnalysisAtAStiffness
    from ._4464 import HypoidGearSetCompoundModalAnalysisAtAStiffness
    from ._4465 import InterMountableComponentConnectionCompoundModalAnalysisAtAStiffness
    from ._4466 import KlingelnbergCycloPalloidConicalGearCompoundModalAnalysisAtAStiffness
    from ._4467 import KlingelnbergCycloPalloidConicalGearMeshCompoundModalAnalysisAtAStiffness
    from ._4468 import KlingelnbergCycloPalloidConicalGearSetCompoundModalAnalysisAtAStiffness
    from ._4469 import KlingelnbergCycloPalloidHypoidGearCompoundModalAnalysisAtAStiffness
    from ._4470 import KlingelnbergCycloPalloidHypoidGearMeshCompoundModalAnalysisAtAStiffness
    from ._4471 import KlingelnbergCycloPalloidHypoidGearSetCompoundModalAnalysisAtAStiffness
    from ._4472 import KlingelnbergCycloPalloidSpiralBevelGearCompoundModalAnalysisAtAStiffness
    from ._4473 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundModalAnalysisAtAStiffness
    from ._4474 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundModalAnalysisAtAStiffness
    from ._4475 import MassDiscCompoundModalAnalysisAtAStiffness
    from ._4476 import MeasurementComponentCompoundModalAnalysisAtAStiffness
    from ._4477 import MountableComponentCompoundModalAnalysisAtAStiffness
    from ._4478 import OilSealCompoundModalAnalysisAtAStiffness
    from ._4479 import PartCompoundModalAnalysisAtAStiffness
    from ._4480 import PartToPartShearCouplingCompoundModalAnalysisAtAStiffness
    from ._4481 import PartToPartShearCouplingConnectionCompoundModalAnalysisAtAStiffness
    from ._4482 import PartToPartShearCouplingHalfCompoundModalAnalysisAtAStiffness
    from ._4483 import PlanetaryConnectionCompoundModalAnalysisAtAStiffness
    from ._4484 import PlanetaryGearSetCompoundModalAnalysisAtAStiffness
    from ._4485 import PlanetCarrierCompoundModalAnalysisAtAStiffness
    from ._4486 import PointLoadCompoundModalAnalysisAtAStiffness
    from ._4487 import PowerLoadCompoundModalAnalysisAtAStiffness
    from ._4488 import PulleyCompoundModalAnalysisAtAStiffness
    from ._4489 import RingPinsCompoundModalAnalysisAtAStiffness
    from ._4490 import RingPinsToDiscConnectionCompoundModalAnalysisAtAStiffness
    from ._4491 import RollingRingAssemblyCompoundModalAnalysisAtAStiffness
    from ._4492 import RollingRingCompoundModalAnalysisAtAStiffness
    from ._4493 import RollingRingConnectionCompoundModalAnalysisAtAStiffness
    from ._4494 import RootAssemblyCompoundModalAnalysisAtAStiffness
    from ._4495 import ShaftCompoundModalAnalysisAtAStiffness
    from ._4496 import ShaftHubConnectionCompoundModalAnalysisAtAStiffness
    from ._4497 import ShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness
    from ._4498 import SpecialisedAssemblyCompoundModalAnalysisAtAStiffness
    from ._4499 import SpiralBevelGearCompoundModalAnalysisAtAStiffness
    from ._4500 import SpiralBevelGearMeshCompoundModalAnalysisAtAStiffness
    from ._4501 import SpiralBevelGearSetCompoundModalAnalysisAtAStiffness
    from ._4502 import SpringDamperCompoundModalAnalysisAtAStiffness
    from ._4503 import SpringDamperConnectionCompoundModalAnalysisAtAStiffness
    from ._4504 import SpringDamperHalfCompoundModalAnalysisAtAStiffness
    from ._4505 import StraightBevelDiffGearCompoundModalAnalysisAtAStiffness
    from ._4506 import StraightBevelDiffGearMeshCompoundModalAnalysisAtAStiffness
    from ._4507 import StraightBevelDiffGearSetCompoundModalAnalysisAtAStiffness
    from ._4508 import StraightBevelGearCompoundModalAnalysisAtAStiffness
    from ._4509 import StraightBevelGearMeshCompoundModalAnalysisAtAStiffness
    from ._4510 import StraightBevelGearSetCompoundModalAnalysisAtAStiffness
    from ._4511 import StraightBevelPlanetGearCompoundModalAnalysisAtAStiffness
    from ._4512 import StraightBevelSunGearCompoundModalAnalysisAtAStiffness
    from ._4513 import SynchroniserCompoundModalAnalysisAtAStiffness
    from ._4514 import SynchroniserHalfCompoundModalAnalysisAtAStiffness
    from ._4515 import SynchroniserPartCompoundModalAnalysisAtAStiffness
    from ._4516 import SynchroniserSleeveCompoundModalAnalysisAtAStiffness
    from ._4517 import TorqueConverterCompoundModalAnalysisAtAStiffness
    from ._4518 import TorqueConverterConnectionCompoundModalAnalysisAtAStiffness
    from ._4519 import TorqueConverterPumpCompoundModalAnalysisAtAStiffness
    from ._4520 import TorqueConverterTurbineCompoundModalAnalysisAtAStiffness
    from ._4521 import UnbalancedMassCompoundModalAnalysisAtAStiffness
    from ._4522 import VirtualComponentCompoundModalAnalysisAtAStiffness
    from ._4523 import WormGearCompoundModalAnalysisAtAStiffness
    from ._4524 import WormGearMeshCompoundModalAnalysisAtAStiffness
    from ._4525 import WormGearSetCompoundModalAnalysisAtAStiffness
    from ._4526 import ZerolBevelGearCompoundModalAnalysisAtAStiffness
    from ._4527 import ZerolBevelGearMeshCompoundModalAnalysisAtAStiffness
    from ._4528 import ZerolBevelGearSetCompoundModalAnalysisAtAStiffness



'''_67.py

IntegrationMethod
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_INTEGRATION_METHOD = python_net_import('SMT.MastaAPI.NodalAnalysis', 'IntegrationMethod')


__docformat__ = 'restructuredtext en'
__all__ = ('IntegrationMethod',)


class IntegrationMethod(Enum):
    '''IntegrationMethod

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _INTEGRATION_METHOD

    __hash__ = None

    NEWMARK = 0
    NEWMARK_ACCELERATION = 1
    WILSON_THETA = 2
    HHT = 3
    RUNGEKUTTA_45_EXPLICIT = 4
    SEMIIMPLICIT_EXTRAPOLATION_METHOD = 5
    BACKWARD_EULER_VELOCITY = 6
    BACKWARD_EULER_ACCELERATION = 7
    LOBATTO3A_ORDER_2 = 8
    LOBATTO3C_ORDER_2 = 9
    ROSENBROCK_43 = 10


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


IntegrationMethod.__setattr__ = __enum_setattr
IntegrationMethod.__delattr__ = __enum_delattr



'''_302.py

MicroGeometryModel
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_MICRO_GEOMETRY_MODEL = python_net_import('SMT.MastaAPI.Gears', 'MicroGeometryModel')


__docformat__ = 'restructuredtext en'
__all__ = ('MicroGeometryModel',)


class MicroGeometryModel(Enum):
    '''MicroGeometryModel

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _MICRO_GEOMETRY_MODEL

    __hash__ = None

    NONE = 0
    ESTIMATED_FROM_MACRO_GEOMETRY = 1
    SPECIFIED_MICRO_GEOMETRY = 2


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


MicroGeometryModel.__setattr__ = __enum_setattr
MicroGeometryModel.__delattr__ = __enum_delattr



'''_262.py

EfficiencyRatingMethod
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_EFFICIENCY_RATING_METHOD = python_net_import('SMT.MastaAPI.Materials.Efficiency', 'EfficiencyRatingMethod')


__docformat__ = 'restructuredtext en'
__all__ = ('EfficiencyRatingMethod',)


class EfficiencyRatingMethod(Enum):
    '''EfficiencyRatingMethod

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _EFFICIENCY_RATING_METHOD

    __hash__ = None

    ISOTR_1417912001 = 0
    ISOTR_1417922001 = 1


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


EfficiencyRatingMethod.__setattr__ = __enum_setattr
EfficiencyRatingMethod.__delattr__ = __enum_delattr



'''_5268.py

CylindricalGearCompoundMultibodyDynamicsAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2232, _2234
from mastapy._internal import constructor, conversion
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.mbd_analyses import _5120
from mastapy.system_model.analyses_and_results.mbd_analyses.compound import _5279
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.Compound', 'CylindricalGearCompoundMultibodyDynamicsAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearCompoundMultibodyDynamicsAnalysis',)


class CylindricalGearCompoundMultibodyDynamicsAnalysis(_5279.GearCompoundMultibodyDynamicsAnalysis):
    '''CylindricalGearCompoundMultibodyDynamicsAnalysis

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearCompoundMultibodyDynamicsAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2232.CylindricalGear':
        '''CylindricalGear: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2232.CylindricalGear.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to CylindricalGear. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_analysis_cases_ready(self) -> 'List[_5120.CylindricalGearMultibodyDynamicsAnalysis]':
        '''List[CylindricalGearMultibodyDynamicsAnalysis]: 'ComponentAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCasesReady, constructor.new(_5120.CylindricalGearMultibodyDynamicsAnalysis))
        return value

    @property
    def planetaries(self) -> 'List[CylindricalGearCompoundMultibodyDynamicsAnalysis]':
        '''List[CylindricalGearCompoundMultibodyDynamicsAnalysis]: 'Planetaries' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Planetaries, constructor.new(CylindricalGearCompoundMultibodyDynamicsAnalysis))
        return value

    @property
    def component_analysis_cases(self) -> 'List[_5120.CylindricalGearMultibodyDynamicsAnalysis]':
        '''List[CylindricalGearMultibodyDynamicsAnalysis]: 'ComponentAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCases, constructor.new(_5120.CylindricalGearMultibodyDynamicsAnalysis))
        return value



'''_5957.py

FlexiblePinAnalysisOptions
'''


from mastapy._internal.implicit import list_with_selected_item
from mastapy.system_model.analyses_and_results.static_loads import _6486, _6493
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.parametric_study_tools import _4085
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.load_case_groups import _5356
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_FLEXIBLE_PIN_ANALYSIS_OPTIONS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.FlexiblePinAnalyses', 'FlexiblePinAnalysisOptions')


__docformat__ = 'restructuredtext en'
__all__ = ('FlexiblePinAnalysisOptions',)


class FlexiblePinAnalysisOptions(_0.APIBase):
    '''FlexiblePinAnalysisOptions

    This is a mastapy class.
    '''

    TYPE = _FLEXIBLE_PIN_ANALYSIS_OPTIONS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'FlexiblePinAnalysisOptions.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def extreme_load_case(self) -> 'list_with_selected_item.ListWithSelectedItem_StaticLoadCase':
        '''list_with_selected_item.ListWithSelectedItem_StaticLoadCase: 'ExtremeLoadCase' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_StaticLoadCase)(self.wrapped.ExtremeLoadCase) if self.wrapped.ExtremeLoadCase else None

    @extreme_load_case.setter
    def extreme_load_case(self, value: 'list_with_selected_item.ListWithSelectedItem_StaticLoadCase.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_StaticLoadCase.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_StaticLoadCase.implicit_type()
        value = wrapper_type[enclosed_type](value.wrapped if value else None)
        self.wrapped.ExtremeLoadCase = value

    @property
    def extreme_load_case_for_stop_start(self) -> '_6486.StaticLoadCase':
        '''StaticLoadCase: 'ExtremeLoadCaseForStopStart' is the original name of this property.'''

        if _6486.StaticLoadCase.TYPE not in self.wrapped.ExtremeLoadCaseForStopStart.__class__.__mro__:
            raise CastException('Failed to cast extreme_load_case_for_stop_start to StaticLoadCase. Expected: {}.'.format(self.wrapped.ExtremeLoadCaseForStopStart.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ExtremeLoadCaseForStopStart.__class__)(self.wrapped.ExtremeLoadCaseForStopStart) if self.wrapped.ExtremeLoadCaseForStopStart else None

    @extreme_load_case_for_stop_start.setter
    def extreme_load_case_for_stop_start(self, value: '_6486.StaticLoadCase'):
        value = value.wrapped if value else None
        self.wrapped.ExtremeLoadCaseForStopStart = value

    @property
    def ldd(self) -> 'list_with_selected_item.ListWithSelectedItem_DutyCycle':
        '''list_with_selected_item.ListWithSelectedItem_DutyCycle: 'LDD' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_DutyCycle)(self.wrapped.LDD) if self.wrapped.LDD else None

    @ldd.setter
    def ldd(self, value: 'list_with_selected_item.ListWithSelectedItem_DutyCycle.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_DutyCycle.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_DutyCycle.implicit_type()
        value = wrapper_type[enclosed_type](value.wrapped if value else None)
        self.wrapped.LDD = value

    @property
    def nominal_load_case(self) -> 'list_with_selected_item.ListWithSelectedItem_StaticLoadCase':
        '''list_with_selected_item.ListWithSelectedItem_StaticLoadCase: 'NominalLoadCase' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_StaticLoadCase)(self.wrapped.NominalLoadCase) if self.wrapped.NominalLoadCase else None

    @nominal_load_case.setter
    def nominal_load_case(self, value: 'list_with_selected_item.ListWithSelectedItem_StaticLoadCase.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_StaticLoadCase.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_StaticLoadCase.implicit_type()
        value = wrapper_type[enclosed_type](value.wrapped if value else None)
        self.wrapped.NominalLoadCase = value

    @property
    def nominal_load_case_for_stop_start(self) -> '_6486.StaticLoadCase':
        '''StaticLoadCase: 'NominalLoadCaseForStopStart' is the original name of this property.'''

        if _6486.StaticLoadCase.TYPE not in self.wrapped.NominalLoadCaseForStopStart.__class__.__mro__:
            raise CastException('Failed to cast nominal_load_case_for_stop_start to StaticLoadCase. Expected: {}.'.format(self.wrapped.NominalLoadCaseForStopStart.__class__.__qualname__))

        return constructor.new_override(self.wrapped.NominalLoadCaseForStopStart.__class__)(self.wrapped.NominalLoadCaseForStopStart) if self.wrapped.NominalLoadCaseForStopStart else None

    @nominal_load_case_for_stop_start.setter
    def nominal_load_case_for_stop_start(self, value: '_6486.StaticLoadCase'):
        value = value.wrapped if value else None
        self.wrapped.NominalLoadCaseForStopStart = value

    @property
    def include_flexible_bearing_races(self) -> 'bool':
        '''bool: 'IncludeFlexibleBearingRaces' is the original name of this property.'''

        return self.wrapped.IncludeFlexibleBearingRaces

    @include_flexible_bearing_races.setter
    def include_flexible_bearing_races(self, value: 'bool'):
        self.wrapped.IncludeFlexibleBearingRaces = bool(value) if value else False



'''_3199.py

WormGearSetCompoundSteadyStateSynchronousResponseAtASpeed
'''


from typing import List

from mastapy.system_model.part_model.gears import _2259
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed.compound import _3197, _3198, _3134
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed import _3069
from mastapy._internal.python_net import python_net_import

_WORM_GEAR_SET_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesAtASpeed.Compound', 'WormGearSetCompoundSteadyStateSynchronousResponseAtASpeed')


__docformat__ = 'restructuredtext en'
__all__ = ('WormGearSetCompoundSteadyStateSynchronousResponseAtASpeed',)


class WormGearSetCompoundSteadyStateSynchronousResponseAtASpeed(_3134.GearSetCompoundSteadyStateSynchronousResponseAtASpeed):
    '''WormGearSetCompoundSteadyStateSynchronousResponseAtASpeed

    This is a mastapy class.
    '''

    TYPE = _WORM_GEAR_SET_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED

    __hash__ = None

    def __init__(self, instance_to_wrap: 'WormGearSetCompoundSteadyStateSynchronousResponseAtASpeed.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2259.WormGearSet':
        '''WormGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2259.WormGearSet)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2259.WormGearSet':
        '''WormGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2259.WormGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def worm_gears_compound_steady_state_synchronous_response_at_a_speed(self) -> 'List[_3197.WormGearCompoundSteadyStateSynchronousResponseAtASpeed]':
        '''List[WormGearCompoundSteadyStateSynchronousResponseAtASpeed]: 'WormGearsCompoundSteadyStateSynchronousResponseAtASpeed' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.WormGearsCompoundSteadyStateSynchronousResponseAtASpeed, constructor.new(_3197.WormGearCompoundSteadyStateSynchronousResponseAtASpeed))
        return value

    @property
    def worm_meshes_compound_steady_state_synchronous_response_at_a_speed(self) -> 'List[_3198.WormGearMeshCompoundSteadyStateSynchronousResponseAtASpeed]':
        '''List[WormGearMeshCompoundSteadyStateSynchronousResponseAtASpeed]: 'WormMeshesCompoundSteadyStateSynchronousResponseAtASpeed' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.WormMeshesCompoundSteadyStateSynchronousResponseAtASpeed, constructor.new(_3198.WormGearMeshCompoundSteadyStateSynchronousResponseAtASpeed))
        return value

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_3069.WormGearSetSteadyStateSynchronousResponseAtASpeed]':
        '''List[WormGearSetSteadyStateSynchronousResponseAtASpeed]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCasesReady, constructor.new(_3069.WormGearSetSteadyStateSynchronousResponseAtASpeed))
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_3069.WormGearSetSteadyStateSynchronousResponseAtASpeed]':
        '''List[WormGearSetSteadyStateSynchronousResponseAtASpeed]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCases, constructor.new(_3069.WormGearSetSteadyStateSynchronousResponseAtASpeed))
        return value



'''_1741.py

LoadedNeedleRollerBearingRow
'''


from mastapy._internal import constructor
from mastapy.bearings.bearing_results.rolling import _1740, _1729
from mastapy._internal.python_net import python_net_import

_LOADED_NEEDLE_ROLLER_BEARING_ROW = python_net_import('SMT.MastaAPI.Bearings.BearingResults.Rolling', 'LoadedNeedleRollerBearingRow')


__docformat__ = 'restructuredtext en'
__all__ = ('LoadedNeedleRollerBearingRow',)


class LoadedNeedleRollerBearingRow(_1729.LoadedCylindricalRollerBearingRow):
    '''LoadedNeedleRollerBearingRow

    This is a mastapy class.
    '''

    TYPE = _LOADED_NEEDLE_ROLLER_BEARING_ROW

    __hash__ = None

    def __init__(self, instance_to_wrap: 'LoadedNeedleRollerBearingRow.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def load_dependent_power_loss(self) -> 'float':
        '''float: 'LoadDependentPowerLoss' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LoadDependentPowerLoss

    @property
    def cage_land_sliding_power_loss(self) -> 'float':
        '''float: 'CageLandSlidingPowerLoss' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CageLandSlidingPowerLoss

    @property
    def speed_dependent_power_loss(self) -> 'float':
        '''float: 'SpeedDependentPowerLoss' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SpeedDependentPowerLoss

    @property
    def total_power_loss(self) -> 'float':
        '''float: 'TotalPowerLoss' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TotalPowerLoss

    @property
    def total_power_loss_traction_coefficient(self) -> 'float':
        '''float: 'TotalPowerLossTractionCoefficient' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TotalPowerLossTractionCoefficient

    @property
    def load_dependent_power_loss_traction_coefficient(self) -> 'float':
        '''float: 'LoadDependentPowerLossTractionCoefficient' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LoadDependentPowerLossTractionCoefficient

    @property
    def speed_dependent_power_loss_traction_coefficient(self) -> 'float':
        '''float: 'SpeedDependentPowerLossTractionCoefficient' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SpeedDependentPowerLossTractionCoefficient

    @property
    def loaded_bearing(self) -> '_1740.LoadedNeedleRollerBearingResults':
        '''LoadedNeedleRollerBearingResults: 'LoadedBearing' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1740.LoadedNeedleRollerBearingResults)(self.wrapped.LoadedBearing) if self.wrapped.LoadedBearing else None
